@@ -185,6 +185,8 @@ def integrate_odes(
             that are functions of the other symbols that are keys in `odes`.
             These values are added to the end of the 2D array field `sol.y` in the object `sol`
             returned by `solve_ivp`, in the order in which they appear in `dependent_variables`.
+            For an example, see the example notebook
+            https://github.com/UC-Davis-molecular-computing/gpac/blob/main/notebook.ipynb.
 
         method:
             See documentation for `solve_ivp` in scipy.integrate:
@@ -316,6 +318,7 @@ def plot(
         dependent_symbols: Optional[Dict[Union[sympy.Symbol, str], Union[sympy.Expr, str]]] = None,
         figure_size: Tuple[float, float] = (10, 3),
         symbols_to_plot: Optional[Iterable[Union[sympy.Symbol, str]]] = None,
+        show: bool = True,
         method: Union[str, OdeSolver] = 'RK45',
         dense_output: bool = False,
         events: Optional[Union[Callable, Iterable[Callable]]] = None,
@@ -336,9 +339,17 @@ def plot(
         symbols_to_plot:
             symbols to plot; if empty, then all symbols are plotted
 
+        show:
+            whether to call matplotlib.pyplot.show() after creating the plot;
+            If False, this helps the user to call other functions
+            such as matplotlib.pyplot.legend() or matplotlib.pyplot.grid(), which will not work if
+            matplotlib.pyplot.show() has already been called.
+
         dependent_symbols:
             dict mapping symbols (or strings) to sympy expressions (or strings) representing variables
             that are functions of the other variables that are keys in `odes`.
+            For an example, see the example notebook
+            https://github.com/UC-Davis-molecular-computing/gpac/blob/main/notebook.ipynb.
 
         options:
             For solver-specific parameters to `solve_ivp`,
@@ -401,7 +412,8 @@ def plot(
 
     plt.xlabel('time')
     plt.legend()
-    plt.show()
+    if show:
+        plt.show()
 
 
 def comma_separated(elts: Iterable[Any]) -> str:
